Apply the lambda to assign a relative importance to each of the previously used methods (WSM and WPM). Lambda values range from zero to one
applyLambda(matrix_wsm, matrix_wpm, lambda)A data frame object that contains the alternatives set scored by and classified in descending order (from best to worst classified) according to the weighting proposed by the WASPAS method using the input lambda.
The data set object obtained from the application of the calcWSM function
The data set object obtained from the application of the calcWPM function
The lambda value (between 0 and 1)