Calculates the ranking for the alternative's set according to WPM method
calcWPM(normal_db, vec_weights)A data frame object that contains 2 columns and the the same number of rows as the input matrix. The columns "WPM_Rank" has the calculated relative value of each alternative whose id is in the "Alternative" column
A data set object with normalized values of Alternatives X Criteria
Contains a set of user assigned values to weight the criteria. The sum of these weights must add up to 1. The format of this input is an array of values.